# TrustedCertificateBundleLabelOperation

The operation by which a label is utilized inside a bundle.  include: all certificates with the specific label name will be included in the bundle exclude: all certificates with the specific label name will be excluded from the bundle 

## Properties
Name | Type | Description | Notes
------------ | ------------- | ------------- | -------------
**value** | **str** | The operation by which a label is utilized inside a bundle.  include: all certificates with the specific label name will be included in the bundle exclude: all certificates with the specific label name will be excluded from the bundle  |  must be one of ["include", "exclude", ]
**any string name** | **bool, date, datetime, dict, float, int, list, str, none_type** | any string name can be used but the value must be the correct type | [optional]

[[Back to Model list]](../README.md#documentation-for-models) [[Back to API list]](../README.md#documentation-for-api-endpoints) [[Back to README]](../README.md)


